summaryrefslogtreecommitdiffstats
path: root/src/searchlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/searchlist.h')
-rw-r--r--src/searchlist.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/src/searchlist.h b/src/searchlist.h
index ffa7ac8..3986b4b 100644
--- a/src/searchlist.h
+++ b/src/searchlist.h
@@ -28,25 +28,25 @@
#ifndef SEARCHLIST_H
#define SEARCHLIST_H
-#include <qwidget.h>
-#include <qvbox.h>
-#include <qlineedit.h>
-#include <qlistview.h>
-#include <qtooltip.h>
+#include <ntqwidget.h>
+#include <ntqvbox.h>
+#include <ntqlineedit.h>
+#include <ntqlistview.h>
+#include <ntqtooltip.h>
class SearchList;
/**
* Defines a line text edit for searchable list view.
* The widget is based on QLineEdit with additional key functions
* Supported key events (up and down) are emitted as signals
* @author Albert Yosher
*/
-class SearchLineEdit : public QLineEdit
+class SearchLineEdit : public TQLineEdit
{
Q_OBJECT
public:
- SearchLineEdit(QWidget* pParent) : QLineEdit(pParent) {};
+ SearchLineEdit(TQWidget* pParent) : TQLineEdit(pParent) {};
~SearchLineEdit() {};
signals:
@@ -55,10 +55,10 @@ signals:
* inside this edit widget.
* @param pEvent The event received for this key press
*/
- void keyPressed(QKeyEvent* pEvent);
+ void keyPressed(TQKeyEvent* pEvent);
private:
- virtual void keyPressEvent(QKeyEvent*);
+ virtual void keyPressEvent(TQKeyEvent*);
};
/**
@@ -67,13 +67,13 @@ private:
* list item.
* @author Gabor Fekete
*/
-class ListToolTip : public QToolTip
+class ListToolTip : public TQToolTip
{
public:
ListToolTip(SearchList* pParent);
protected:
- virtual void maybeTip(const QPoint& pt);
+ virtual void maybeTip(const TQPoint& pt);
private:
/** The owner widget. */
@@ -88,18 +88,18 @@ private:
* set to point to the first item that matches the new text.
* @author Elad Lahav
*/
-class SearchList : public QVBox
+class SearchList : public TQVBox
{
Q_OBJECT
public:
- SearchList(int nSearchCol, QWidget* pParent = 0, const char* szName = 0);
+ SearchList(int nSearchCol, TQWidget* pParent = 0, const char* szName = 0);
~SearchList();
/**
* @return A pointer to the list part of the widget.
*/
- QListView* getList() { return m_pList; }
+ TQListView* getList() { return m_pList; }
/**
* Constructs a tool-tip for the given item.
@@ -107,30 +107,30 @@ public:
* @param sTip The constructed tip string (on return)
* @return True to display the tip, false otherwise
*/
- virtual bool getTip(QListViewItem* pItem, QString& sTip) = 0;
+ virtual bool getTip(TQListViewItem* pItem, TQString& sTip) = 0;
public slots:
void slotSetFocus();
protected:
/** The search edit-box. */
- QLineEdit* m_pEdit;
+ TQLineEdit* m_pEdit;
/** The list part of the widget. */
- QListView* m_pList;
+ TQListView* m_pList;
/**
* Called whenever the user selects an item in the list by either double-
* clicking it, or by highlighting the item and pressing the ENTER key.
* @param pItem The selected list item
*/
- virtual void processItemSelected(QListViewItem* pItem) = 0;
+ virtual void processItemSelected(TQListViewItem* pItem) = 0;
protected slots:
- void slotFindItem(const QString&);
- void slotItemSelected(QListViewItem*);
+ void slotFindItem(const TQString&);
+ void slotItemSelected(TQListViewItem*);
void slotItemSelected();
- void slotKeyPressed(QKeyEvent*);
+ void slotKeyPressed(TQKeyEvent*);
private:
/** Specifies the search column, i.e., the list column whose strings are
@@ -28,25 +28,25 @@
/**
* Defines a line text edit for searchable list view.
- * The widget is based on QLineEdit with additional key functions
+ * The widget is based on TQLineEdit with additional key functions
* Supported key events (up and down) are emitted as signals
* @author Albert Yosher